
{% extends "admin/base_site.html" %}
{% block content %}
  <h1>{{ title }}</h1>
  <form method="post" style="max-width: 520px;">
    {% csrf_token %}
    <input type="hidden" name="ids" value="{{ ids }}">
    <fieldset class="module aligned">
      {{ form.as_p }}
    </fieldset>
    <p><strong>Elementi selezionati:</strong> {{ queryset|length }}</p>
    <div class="submit-row">
      <input type="submit" value="Assegna permessi al Gruppo" class="default">
      <a href="{% url 'admin:audit_missingpermission_changelist' %}" class="button cancel-link">Annulla</a>
    </div>
  </form>
{% endblock %}
